import dotenv from 'dotenv';
import path from 'path';
import { DEFAULT_THEME_ID } from '../utils/themes';

// Load environment variables
dotenv.config();

interface CatBotConfig {
  token: string;
  messageResponseChance: number;
  voiceChannelConfig: {
    minJoinInterval: number;
    maxJoinInterval: number;
    minStayDuration: number;
    maxStayDuration: number;
    minMeowInterval: number;
    maxMeowInterval: number;
  };
  catPersonalization: {
    pronoun: string;
  };
  audioFilesDir: string;
  statusUpdateInterval: number;
  defaultTheme: string;
}

export const config: CatBotConfig = {
  token: process.env.DISCORD_TOKEN || '',
  messageResponseChance: Number(process.env.MESSAGE_RESPONSE_CHANCE || 10),
  voiceChannelConfig: {
    minJoinInterval: Number(process.env.MIN_VOICE_JOIN_INTERVAL || 300),
    maxJoinInterval: Number(process.env.MAX_VOICE_JOIN_INTERVAL || 1800),
    minStayDuration: Number(process.env.MIN_VOICE_STAY_DURATION || 60),
    maxStayDuration: Number(process.env.MAX_VOICE_STAY_DURATION || 300),
    minMeowInterval: Number(process.env.MIN_VOICE_MEOW_INTERVAL || 5),
    maxMeowInterval: Number(process.env.MAX_VOICE_MEOW_INTERVAL || 30),
  },
  catPersonalization: {
    pronoun: process.env.CAT_PRONOUN || 'their',
  },
  audioFilesDir: process.env.AUDIO_FILES_DIR || path.join(__dirname, '..', 'audio'),
  statusUpdateInterval: Number(process.env.STATUS_UPDATE_INTERVAL || 300), // 5 minutes
  defaultTheme: process.env.DEFAULT_THEME || DEFAULT_THEME_ID,
};

// Validate required configuration
if (!config.token) {
  throw new Error('Missing Discord bot token in environment variables');
}

// Audio files directory - using environment variable or default path
const AUDIO_DIR = process.env.AUDIO_DIR || path.join(__dirname, '..', 'audio');
export const AUDIO_FILES_DIR = AUDIO_DIR;
