import { getRandomElement } from './random';
import { guildSettings } from './guild-settings';
import { getTheme } from './themes';

/**
 * Get a random vocalization or action for a guild
 */
export function getRandomBehavior(guildId: string): string {
  // Get guild settings
  const settings = guildSettings.getSettings(guildId);
  
  // Get theme
  const theme = getTheme(settings.themeId);
  
  // 50/50 chance of vocalization vs action
  if (Math.random() < 0.5) {
    return getRandomElement(theme.vocalizations);
  } else {
    // Replace PRONOUN placeholder with the guild's pronoun setting
    const action = getRandomElement(theme.actions);
    return `*${action.replace('PRONOUN', settings.pronoun)}*`;
  }
}

/**
 * Get audio file prefix for a guild based on its theme
 */
export function getAudioFilePrefix(guildId: string): string {
  const settings = guildSettings.getSettings(guildId);
  const theme = getTheme(settings.themeId);
  return theme.audioFilePrefix;
}

/**
 * Get response chance for a guild
 */
export function getResponseChance(guildId: string): number {
  const settings = guildSettings.getSettings(guildId);
  return settings.responseChance;
}

/**
 * Get a random status message to display
 */
export function getRandomStatusMessage(totalGuilds: number): string {
  // Get a random theme for variety
  const themeIds = Object.keys(getTheme(''));
  const randomThemeId = getRandomElement(themeIds);
  const theme = getTheme(randomThemeId);
  
  // Get a random status message
  let statusMessage = getRandomElement(theme.statusMessages.normal);
  
  // Replace GUILD_COUNT placeholder with actual count
  statusMessage = statusMessage.replace('GUILD_COUNT', totalGuilds.toString());
  
  return statusMessage;
}

/**
 * Get the emoji icon for a guild's theme
 */
export function getThemeEmoji(guildId: string): string {
  const settings = guildSettings.getSettings(guildId);
  const theme = getTheme(settings.themeId);
  return theme.emojiIcon;
}
